/**
 * PDF417 - 2D Barcode generator (LGPLv3)
 * Ported from PHP - PDF417 class, version 1.0.005, from TCPDF library (http://www.tcpdf.org/)
 * Original port by bkuzmic: https://github.com/bkuzmic/pdf417-js
 */
export declare const PDF417: {
    ROWHEIGHT: number;
    QUIETH: number;
    QUIETV: number;
    barcode_array: {};
    start_pattern: string;
    stop_pattern: string;
    /**
     * Array of text Compaction Sub-Modes (values 0xFB - 0xFF are used for submode changers).
     */
    textsubmodes: number[][];
    /**
     * Array of switching codes for Text Compaction Sub-Modes.
     */
    textlatch: {
        '01': number[];
        '02': number[];
        '03': number[];
        '10': number[];
        '12': number[];
        '13': number[];
        '20': number[];
        '21': number[];
        '23': number[];
        '30': number[];
        '31': number[];
        '32': number[];
    };
    /**
     * Clusters of codewords (0, 3, 6)<br/>
     * Values are hex equivalents of binary representation of bars (1 = bar, 0 = space).<br/>
     * The codewords numbered from 900 to 928 have special meaning, some enable to switch between modes in order to optimise the code:
     * <ul>
     * <li>900 : Switch to "Text" mode</li>
     * <li>901 : Switch to "Byte" mode</li>
     * <li>902 : Switch to "Numeric" mode</li>
     * <li>903 - 912 : Reserved</li>
     * <li>913 : Switch to "Octet" only for the next codeword</li>
     * <li>914 - 920 : Reserved</li>
     * <li>921 : Initialization</li>
     * <li>922 : Terminator codeword for Macro PDF control block</li>
     * <li>923 : Sequence tag to identify the beginning of optional fields in the Macro PDF control block</li>
     * <li>924 : Switch to "Byte" mode (If the total number of byte is multiple of 6)</li>
     * <li>925 : Identifier for a user defined Extended Channel Interpretation (ECI)</li>
     * <li>926 : Identifier for a general purpose ECI format</li>
     * <li>927 : Identifier for an ECI of a character set or code page</li>
     * <li>928 : Macro marker codeword to indicate the beginning of a Macro PDF Control Block</li>
     * </ul>
     */
    clusters: number[][];
    /**
     * Array of factors of the Reed-Solomon polynomial equations used for error correction; one sub array for each correction level (0-8).
     * @protected
     */
    rsfactors: number[][];
    /**
     * This is the class constructor.
     * Creates a PDF417 object
     * @param code (string) code to represent using PDF417
     * @param ecl (int) error correction level (0-8); default -1 = automatic correction level
     * @param aspectratio (float) the width to height of the symbol (excluding quiet zones)
     */
    init: (code: any, ecl: any, aspectratio: any) => boolean;
    getInputSequences: (code: any) => any[];
    getCompaction: (mode: any, code: any, addmode: any) => any[];
    getErrorCorrectionLevel: (ecl: any, numcw: any) => any;
    getErrorCorrection: (cw: any, ecl: any) => any;
    getBarcodeArray: () => any;
    /**
     *
     * Functions from phpjs.org
     *
     */
    _array_fill: (start_index: any, num: any, mixed_val: any) => {};
    _str_repeat: (input: any, multiplier: any) => string;
    _intval: (mixed_var: any, base: any) => any;
    _sprintf: () => any;
    _preg_split: (pattern: any, subject: any, limit: any, flags: any) => any[];
    _ord: (string: any) => any;
    _array_search: (needle: any, haystack: any, argStrict: any) => any;
    _my_bcmod: (x: any, y: any) => number;
};
